@@ -4,12 +4,12 @@ test_that("require_namespace", {
   expect_true(require_namespace("base", "methods", "stats"))
 
   # custom error on failure
-  expect_error(require_namespace("1"), class = "fuj:namespaceError")
+  expect_error(require_namespace("1"), class = "namespaceError")
 
   # only the first package should cause an error
   expect_error(
     require_namespace("base", "1foo", "2foo"),
-    class = "fuj:namespaceError",
+    class = "namespaceError",
     regexp = cond_namespace("1foo")$message,
     fixed = TRUE
   )
@@ -17,8 +17,15 @@ test_that("require_namespace", {
   # this should fail because we shouldn't see 2foo
   expect_error(expect_error(
     require_namespace("base", "1foo", "2foo"),
-    class = "fuj:namespaceError",
+    class = "namespaceError",
     regexp = "2foo",
     fixed = TRUE
   ))
+
+  expect_error(require_namespace("base>1.0"), NA)
+  expect_error(require_namespace("utils>=1.0"), NA)
+  expect_error(require_namespace("utils>1.0"), NA)
+  expect_error(require_namespace(paste0("utils==", getRversion())), NA)
+  expect_error(require_namespace("utils<1.0"), class = "namespaceVersionError")
+  expect_error(require_namespace("utils<=1.0"), class = "namespaceVersionError")
 })
